"""Base class implementation for that has JavaScript dictionary
data structure.
"""


class DictionaryStructure:
    """
    Base class implementation for that has JavaScript
    dictionary data structure.

    The apysc treats an instance that inherits this base
    class as dictionary value in JavaScript (e.g., assert_equal
    dictionary type branch instruction).
    """
