"""This module is for the translation mapping data of the
following document:

Document file: animation_base_start.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {

    '# AnimationBase class start interface':
    '',

    'This page explains the `AnimationBase` class `start` method interface.':  # noqa
    '',

    '## What interface is this?':
    '',

    'The `start` method interface starts the target animation. This interface returns the `AnimationBase` subclass instance is when you call each animation interface, such as the `animation_move` or `animation_x`\\, and it has the `start` method.':  # noqa
    '',

    '## Basic usage':
    '',

    'Notes: you need to call the `start` method to start an animation after the calling of the animation method, such as the `animation_x`\\, as follows:':  # noqa
    '',

    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    stage_width=200, stage_height=150, background_color=\'#333\',\n    stage_elem_id=\'stage\')\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=\'#0af\')\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(\n    x=50, y=50, width=50, height=50)\n\nanimation_x: ap.AnimationX = rectangle.animation_x(\n    x=100, duration=3000, delay=3000)\nanimation_x.start()\n\nap.save_overall_html(\n    dest_dir_path=\'./animation_base_start_basic_usage_1/\')\n```':  # noqa
    '',

    '<iframe src="static/animation_base_start_basic_usage_1/index.html" width="200" height="150"></iframe>\n\nYou can also use the method chain for code simplicity:':  # noqa
    '',

    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    stage_width=200, stage_height=150, background_color=\'#333\',\n    stage_elem_id=\'stage\')\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=\'#0af\')\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(\n    x=50, y=50, width=50, height=50)\n\nrectangle.animation_x(x=100, duration=3000, delay=3000).start()\n\nap.save_overall_html(\n    dest_dir_path=\'./animation_base_start_basic_usage_2/\')\n```':  # noqa
    '',

    '<iframe src="static/animation_base_start_basic_usage_2/index.html" width="200" height="150"></iframe>':  # noqa
    '',

    '## start API':
    '',

    '<!-- Docstring: apysc._animation.animation_base.AnimationBase.start -->\n\n<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>\n\n**[Interface signature]** `start(self) -> \'AnimationBase\'`<hr>\n\n**[Interface summary]** Start an animation with current settings.<hr>\n\n**[Returns]**\n\n- `self`: AnimatonBase\n  - This instance.\n\n<hr>\n\n**[Examples]**':  # noqa
    '',

    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=\'#0af\')\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50)\n>>> _ = rectangle.animation_x(x=100).start()\n```':  # noqa
    '',

}
