"""This module is for the constants definitions of
the expression's variable names.
"""

from typing_extensions import Final

DOCUMENT: Final[str] = 'document'
BLANK_OBJECT: Final[str] = 'bo'
DISPLAY_OBJECT: Final[str] = 'do'
PARENT: Final[str] = 'parent'
GRAPHICS: Final[str] = 'g'
POINT2D: Final[str] = 'p2d'
RECTANGLE: Final[str] = 'rect'
CIRCLE: Final[str] = 'circle'
ELLIPSE: Final[str] = 'ellipse'
LINE: Final[str] = 'line'
POLYLINE: Final[str] = 'pline'
POLYGON: Final[str] = 'poly'
PATH: Final[str] = 'path'
SPRITE: Final[str] = 'sp'
ARRAY: Final[str] = 'arr'
DICTIONARY: Final[str] = 'dct'
INDEX: Final[str] = 'idx'
BOOLEAN: Final[str] = 'b'
INT: Final[str] = 'i'
NUMBER: Final[str] = 'n'
STRING: Final[str] = 's'
SNAPSHOT: Final[str] = 'snapshot'
ANY: Final[str] = 'any'
EVENT: Final[str] = 'evt'
MOUSE_EVENT: Final[str] = 'mevt'
WHEEL_EVENT: Final[str] = 'wevt'
TIMER_EVENT: Final[str] = 'tevt'
ANIMATION_EVENT: Final[str] = 'aevt'
ANIMATION_PARALLEL_EVENT: Final[str] = 'apevt'
TIMER: Final[str] = 'timer'
ANIMATION_MOVE: Final[str] = 'animmove'
ANIMATION_X: Final[str] = 'animx'
ANIMATION_Y: Final[str] = 'animy'
ANIMATION_CX: Final[str] = 'animcx'
ANIMATION_CY: Final[str] = 'animcy'
ANIMATION_WIDTH: Final[str] = 'animwidth'
ANIMATION_HEIGHT: Final[str] = 'animheight'
ANIMATION_WIDTH_FOR_ELLIPSE: Final[str] = 'animwidthforellipse'
ANIMATION_HEIGHT_FOR_ELLIPSE: Final[str] = 'animheightforellipse'
ANIMATION_FILL_ALPHA: Final[str] = 'animfillalpha'
ANIMATION_FILL_COLOR: Final[str] = 'animfillcolor'
ANIMATION_LINE_COLOR: Final[str] = 'animlinecolor'
ANIMATION_LINE_ALPHA: Final[str] = 'animlinealpha'
ANIMATION_LINE_THICKNESS: Final[str] = 'animlinethickness'
ANIMATION_RADIUS: Final[str] = 'animradius'
ANIMATION_SKEW_X: Final[str] = 'animskewx'
ANIMATION_SKEW_Y: Final[str] = 'animskewy'
ANIMATION_ROTATION_AROUND_CENTER: Final[str] = 'animrotardcenter'
ANIMATION_ROTATION_AROUND_POINT: Final[str] = 'animrotardpoint'
ANIMATION_SCALE_X_FROM_CENTER: Final[str] = 'animscalexfromcenter'
ANIMATION_SCALE_Y_FROM_CENTER: Final[str] = 'animscaleyfromcenter'
ANIMATION_SCALE_X_FROM_POINT: Final[str] = 'animscalexfrompoint'
ANIMATION_SCALE_Y_FROM_POINT: Final[str] = 'animscaleyfrompoint'
ANIMATION_PARALLEL: Final[str] = 'animparallel'
